#!/bin/bash

CIPHER="$1"	# cipher to use
KATFILE="$2"	# file with known-answer-test values in NIST's
		# ecb_tbl.txt format should be given on stdin.

if [ ! -x ./test_cipher ]; then
    echo "test_cipher binary not found!"
    exit 1
fi

[ "$#" -ne 2 ] && cat <<EOF && exit 1
usage: $0 ciphername ecb_tbl.txt

    where ciphername is a cipher known to the cryptoapi and
    ecb_tbl.txt is a file with known-answer test values in the
    format that NIST required from all of the AES submitters:

    It consists of a series of four-line blocks:

    I=...    (test number)
    KEY=...  (key in ascii hex)
    PT=...   (plain text in ascci hex)
    CT=...   (ciphertext in ascii text)

    (in this order or at least with CT= as the last one of them),
    delimited by blank lines. A line of the form

    KEYSIZE=number

    is used to indicate the key length in bits, but is ignored
    by this program.
EOF

KEYSIZE=0
I=0
KEY=""
PT=""
CT=""
oCT=""

TEST_OK=0
TEST_FAIL=0
COUNT=0

grep -E '^I=|^KEY=|^KEYSIZE=|^PT=|^CT=' "$KATFILE" | ( \
while read; do
    eval "$REPLY"
    if [ "$CT" != "$oCT" ]; then
	echo -n "Test ${I} @ ${KEYSIZE} bits: "
	./test_cipher -c "$CIPHER" -k "$KEY" -p "$PT" -e "$CT"  
	if [ $? -eq 0 ]; then
	    echo OK 
            let TEST_OK+=1
	else
	    echo FAILED
	    let TEST_FAIL+=1
	fi
	let COUNT+=1
	oCT="$CT"
    fi
done

cat <<EOF

Summary:
 CIPHER: $CIPHER
 FILE:   $KATFILE
 OK:     $TEST_OK
 FAIL:   $TEST_FAIL
 TOTAL:  $COUNT

EOF
)